"""

"""

import logging

from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
from sqlalchemy.orm import sessionmaker

DB_PATH = "db/db.sqlite"
BUILD_PATH = "db/build.sql"
DATABASE_URL = "sqlite:///db/db.sqlite"
DATABASE_ASYNC_URL = "sqlite+aiosqlite:///db/db.sqlite"

log = logging.getLogger(__name__)


class DatabaseManager:
    """
    Asynchronous database context manager for sqlite3.
    """

    def __init__(self, database_url=DATABASE_ASYNC_URL):
        self.engine = create_async_engine(database_url, future=True)
        self.session_maker = sessionmaker(self.engine, class_=AsyncSession)
        self.session = None

    async def __aenter__(self):
        self.session = self.session_maker()
        log.debug("Database connection open")
        return self

    async def __aexit__(self, *_):
        await self.session.close()
        await self.session.commit()
        self.session = None
        await self.engine.dispose()
        log.debug("Database connection closed")
