"""
Entry point for the application.
Run this file to get started.
"""

import logging
import asyncio

from bot import DiscordBot
from logs import setup_logs, update_log_levels

async def main():
    """
    Entry point function for the application.
    Run this function to get started.
    """

    # Grab the token before anything else, because if there is no token
    # available then the bot cannot be started anyways.
    with open("TOKEN", "r") as token_file:
        token = token_file.read()

    if not token:
        raise ValueError("Token file is empty")

    setup_logs()
    update_log_levels(
        ('discord', 'PIL', 'urllib3', 'aiosqlite', 'charset_normalizer'),
        level=logging.WARNING
    )

    async with DiscordBot() as bot:
        await bot.load_extensions()
        await bot.start(token)

if __name__ == "__main__":

    asyncio.run(main())
